@@ -2,9 +2,9 @@
 
 import time
 import unittest
-from stack_watcher import (
-    Retriever, Question, Notifier, RulesMixin, ClassLoader
-)
+
+from stack_watcher import (ClassLoader, Notifier, Question, Retriever,
+                           RulesMixin)
 
 # Python 3
 try:
